# Visualization Reference

## Map visualizations

::: geo_track_analyzer.visualize.plot_track_line_on_map
::: geo_track_analyzer.visualize.plot_track_enriched_on_map
::: geo_track_analyzer.visualize.plot_track_2d

## Track profile

::: geo_track_analyzer.visualize.plot_track_with_slope
::: geo_track_analyzer.visualize.plot_segments_on_map

## Other track visualizations

::: geo_track_analyzer.visualize.plot_track_3d

## Summary visualizations

::: geo_track_analyzer.visualize.plot_track_zones
::: geo_track_analyzer.visualize.plot_segment_zones
::: geo_track_analyzer.visualize.plot_segment_summary
::: geo_track_analyzer.visualize.plot_segment_box_summary